pub enum SpatialRelationType {
Companion,
Neutral,
Antagonist,
Ambivalent,
}Expand description
Specifies the type of spatial relation between two plants.
Variants
Companion
If a plant works well with another plant.
Neutral
If a plant is known to be neutral with another plant.
Antagonist
If a plant doesn’t work well with another plant.
Ambivalent
If a plant is a companion and an antagonist to another plant at the same time.